#
# spec file for package patterns-micro
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with betatest

Name:           patterns-micro
VCS: https://src.suse.de/ALP-pool/patterns-micro#ec08cb224d78b45a7a2e98a15b3a6f081db4ae32
Version:        6.0
Release:        3.1
Summary:        Patterns for SUSE Linux Micro
License:        MIT
Group:          Metapackages
URL:            http://en.opensuse.org/Patterns
Source0:        %name.rpmlintrc
ExclusiveArch:  x86_64 %arm32 aarch64 ppc64le s390x riscv64

%description
This is an internal package that is used to create the patterns as part
of the installation source setup. Installation of this package does
not make sense.

%package defaults
Summary:        SL Micro defaults
Group:          Metapackages
Provides:       pattern() = micro_defaults
Provides:       pattern-category() = SL-Micro
Provides:       pattern-icon() = pattern-kubic
Provides:       pattern-order() = 9020
Obsoletes:      patterns-microos-defaults
Provides:       patterns-microos-defaults
Requires:       audit
Requires:       systemd-coredump
Requires:       pattern() = base
Requires:	suseconnect-ng
Requires:	rollback-helper
# jsc#SMO-376 - pick the SL-Micro flavor
Requires:       (registries-conf-suse if libcontainers-common)

%description defaults
This provides default packages for SUSE Linux Micro which can be optionally
replaced by alternatives.

%package elemental_client
Summary:        Elemental Client
Group:          Metapackages
Provides:       pattern() = micro_elemental_client
Provides:       pattern-category() = SL-Micro
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9055
Provides:       pattern-visible()
Requires:       elemental

%description elemental_client
This are packages which are required to run Elemental Client on SL Micro

%package onlyDVD
Summary:        Packages only for the DVD of SL Micro
Group:          Metapackages
Provides:       pattern-category() = SL-Micro
Requires:       bcache-tools
Requires:       crda
Requires:       cryptsetup
Requires:       firewalld
Requires:       iscsiuio
#extra items for DVD, not every install
Requires:       ModemManager
Requires:       NetworkManager-wwan
Requires:       lvm2
Requires:       multipath-tools
Requires:       nvme-cli
Requires:       open-iscsi
%ifarch %ix86 x86_64 aarch64
Requires:       hyper-v
Requires:       open-vm-tools
%endif
Requires:       pam_pwquality
Requires:       policycoreutils-python-utils
Requires:       qemu-guest-agent
Requires:       spice-vdagent
# Removed due to the installer not based on Linuxrc
# Requires:       tftpboot-installation-openSUSE-MicroOS-%{_target_cpu}
%ifarch %ix86 x86_64
Requires:       ucode-amd
Requires:       ucode-intel
%endif
Requires:       wpa_supplicant
Requires:       man
Provides:       pattern() = micro_onlyDVD
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9900
Requires:       pattern() = cloud
Requires:       pattern() = hardware
Requires:       pattern() = ima_evm
Requires:       pattern() = ra_agent
Requires:       pattern() = sssd_ldap

%description onlyDVD
Additional packages on a SL Micro DVD.

%package alt_onlyDVD
Summary:        Alternative Packages only for the DVD of SL Micro
Group:          Metapackages
Provides:       pattern-category() = SL-Micro
Requires:       kernel-default-base
Provides:       pattern() = micro_alt_onlyDVD
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 9901
Requires:       pattern() = cloud
Requires:       pattern() = cockpit
Requires:       pattern() = ima+evm
Requires:       pattern() = ra+verifier
Requires:       pattern() = selinux
Requires:       pattern() = salt_minion
Requires:       pattern() = sssd_ldap
Requires:       pattern() = micro_elemental_client

%description alt_onlyDVD
Alternative additional packages on a SL Micro DVD.

%prep
# empty on purpose

%build
# empty on purpose

%install
mkdir -p %{buildroot}%{_docdir}/patterns-micro/
PATTERNS='
    defaults elemental_client
    onlyDVD alt_onlyDVD
'
for i in $PATTERNS; do
    echo "This file marks the pattern $i to be installed." \
        > %{buildroot}%{_docdir}/patterns-micro/${i}.txt
done

%files defaults
%dir %{_docdir}/patterns-micro
%{_docdir}/patterns-micro/defaults.txt

%files elemental_client
%dir %{_docdir}/patterns-micro
%{_docdir}/patterns-micro/elemental_client.txt

%files onlyDVD
%dir %{_docdir}/patterns-micro
%{_docdir}/patterns-micro/onlyDVD.txt

%files alt_onlyDVD
%dir %{_docdir}/patterns-micro
%{_docdir}/patterns-micro/alt_onlyDVD.txt

%changelog
* Fri May  3 2024 jsrain@suse.com
- rename of registries-conf to registries-conf-suse
* Fri Apr 26 2024 jsrain@suse.com
- make sure to prefer registries-conf-sl-micro (jsc#SMO-376)
* Tue Apr 16 2024 jsrain@suse.com
- remove apparmor-utils
* Thu Apr  4 2024 jsrain@suse.com
- split off from patterns-base (patterns specific for Micro
  product)
* Mon Mar 11 2024 giacomo.leidi@suse.com
- fix typo in libopenssl3 (bsc#1217934)
* Thu Feb 29 2024 meissner@suse.com
- add libopenssl-3-fips-provider and crypto-policies-scripts
  as requires for the FIPS pattern. (bsc#1220390 bsc#1217361)
- rename fips pattern to provide pattern() = fips for use by people
  using zypper in -t pattern fips (bsc#1220390 bsc#1213798)
* Fri Feb 23 2024 jsrain@suse.com
- include cockpit metapackage in the cockpit pattern
* Wed Feb 14 2024 jsrain@suse.com
- removed haveged (bsc#1219910)
* Tue Feb 13 2024 jsrain@suse.com
- add adcli, sssd-ad and sssd-krb5 to sssd pattern (jsc#SMO-292)
* Thu Jan 18 2024 jsrain@suse.com
- include systemd-status-mail (jsc#PED-6478)
* Thu Jan 18 2024 jsrain@suse.com
- include specific systemd presets for transactional systems
- remove the obsolete base_zypper pattern
* Wed Jan 17 2024 jsrain@suse.com
- use mailx instead of postfix in the transactional pattern
  (jsc#PED-6478)
* Thu Jan 11 2024 jsrain@suse.com
- include postfix in transactional pattern (jsc#PED-6478)
* Fri Jan  5 2024 jsrain@suse.com
- add content of hte elemental pattern (jsc#SMO-303)
- include man in the onlyDVD pattern (bsc#1218539)
* Tue Jan  2 2024 jsrain@suse.com
- add skeleton for elemental client pattern (jsc#SMO-303)
- fix KVM pattern dependency on aarch64 and ppc64le (no qemu-kvm)
* Tue Dec 19 2023 jsrain@suse.com
- obsolete SLE Micro patterns
* Thu Dec 14 2023 jsrain@suse.com
- introduce separate transactional and traditional flavor of base
  pattern
- include crypto-policies-scripts (bsc#1217991)
* Fri Dec  8 2023 jsrain@suse.com
- adjusted the content of KVM pattern
* Thu Nov 30 2023 jsrain@suse.com
- added more missing packages to the patterns (bsc#1216416)
- explicitly require lzop for KVM patern (bsc#1217702)
* Mon Nov 27 2023 jsrain@suse.com
- removed desktop patterns
- added missing packages to the patterns (bsc#1216447, #1216445)
- removed vm-install from KVM pattern
* Mon Nov 27 2023 jsrain@suse.com
- Added missing packages in several patterns for parity with
  SLE Micro 5.x (bsc#1216416, #1216449, #1216447, #1216417)
- Added the KVM host pattern
* Thu Nov 16 2023 fcrozat@suse.com
- Bump to 6.0
- Resync with patterns-microos (add coreutils-systemd and make
  some dependencies conditional to grub2)
* Thu Sep  7 2023 jsrain@suse.com
- Fix building the FIPS pattern (define its filelist)
- Include toolbox for transactional systems
- Include pam_pwquality (bsc#1214886)
* Fri Jul 28 2023 meissner@suse.com
- Added fips pattern. jsc#PED-2735
* Thu Jun 15 2023 kukuk@suse.com
- Add wtmpdb as Y2038 safe wtmp replacement to base [jsc#PED-3304]
* Mon May 29 2023 jsrain@suse.com
- update the build key to be used
- temporarily remove branding
- add salt_minion pattern
* Mon May 15 2023 jsrain@suse.com
- adjusted some pattern names
- remove several unneeded patrerns
* Wed May 10 2023 jsrain@suse.com
- initial versino based on openSUSE MicroOS patterns
